@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+"""Read and set config parameters."""
 
 import os
 import sys
@@ -9,7 +10,7 @@ except ImportError:                  # pragma: no cover
 import socket
 from . import config
 from . import registry
-from .dev.helpers import in_virtual
+from .dev.lab import in_virtual
 
 # NOTE: THIS CODE RUNS ON IMPORT!
 
@@ -31,19 +32,22 @@ try:
     with open(os.path.join(pkg_path, 'isbntools.conf.py'), 'r') as f:
         conf.readfp(f)
     # read user options
-    if in_virtual():
-        conf.read([os.path.join(sys.prefix, 'isbntools.conf')])
+    if in_virtual():                 # pragma: no cover
+        conf.files = conf.read([os.path.join(sys.prefix, 'isbntools.conf')])
     else:
         if os.name == 'nt':          # pragma: no cover
-            conf.read([os.path.join(os.getenv('APPDATA'),
-                      'isbntools/isbntools.conf')])
+            conf.files = conf.read([
+                os.path.join(os.getenv('APPDATA'), 'isbntools/isbntools.conf')
+            ])
         else:                        # pragma: no cover
-            conf.read(['/etc/.isbntools/isbntools.conf',
-                       '/usr/local/isbntools.conf',
-                       '/usr/local/bin/isbntools.conf',
-                       os.path.expanduser('~/.isbntools.conf'),
-                       os.path.expanduser('~/.local/.isbntools/isbntools.conf'),
-                       os.path.expanduser('~/.isbntools/isbntools.conf')])
+            conf.files = conf.read([
+                '/etc/.isbntools/isbntools.conf',
+                '/usr/local/bin/isbntools.conf',
+                '/usr/local/isbntools.conf',
+                os.path.expanduser('~/.isbntools.conf'),
+                os.path.expanduser('~/.local/.isbntools/isbntools.conf'),
+                os.path.expanduser('~/.isbntools/isbntools.conf'),
+            ])
 
     if conf.has_section('SYS'):
         # get user defined values for timeouts
@@ -68,6 +72,10 @@ try:
             if plugin:
                 registry.add_service(o, plugin.query)
 
+    if conf.has_section('MISC'):     # pragma: no cover
+        for o, v in conf.items('MISC'):
+            config.set_option(o.upper(), v)
+
     if conf.has_section('MODULES'):  # pragma: no cover
         for o, v in conf.items('MODULES'):
             config.set_option(o.upper(), v)
